@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
-import sys
 import os
+import platform
 import socket
 import struct
 import select
@@ -14,7 +14,7 @@ import functools
 import errors
 from enums import ICMP_DEFAULT_CODE, IcmpType, IcmpTimeExceededCode, IcmpDestinationUnreachableCode
 
-__version__ = "2.6.6"
+__version__ = "2.8.0"
 DEBUG = False  # DEBUG: Show debug info for developers. (default False)
 EXCEPTIONS = False  # EXCEPTIONS: Raise exception when delay is not available.
 LOGGER = None  # LOGGER: Record logs into console or file.
@@ -47,7 +47,7 @@ def _debug(*args, **kwargs):
         return None
     global LOGGER
     LOGGER = LOGGER or get_logger()
-    message = " ".join([str(item) for item in args])
+    message = " ".join(str(item) for item in args)
     LOGGER.debug(message)
 
 
@@ -75,7 +75,7 @@ def _func_logger(func: callable) -> callable:
     """
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        pargs = ", ".join(["'{}'".format(arg) if isinstance(arg, str) else arg for arg in args])
+        pargs = ", ".join("'{}'".format(arg) if isinstance(arg, str) else arg for arg in args)
         kargs = str(kwargs) if kwargs else ""
         all_args = ", ".join((pargs, kargs)) if (pargs and kargs) else (pargs or kargs)
         _debug("Function Called:", "{func.__name__}({})".format(all_args, func=func))
@@ -145,7 +145,7 @@ def read_ip_header(raw: bytes) -> dict:
         A map contains the infos from the raw header.
     """
     def stringify_ip(ip: int) -> str:
-        return ".".join([str(ip >> offset & 0xff) for offset in (24, 16, 8, 0)])  # str(ipaddress.ip_address(ip))
+        return ".".join(str(ip >> offset & 0xff) for offset in (24, 16, 8, 0))  # str(ipaddress.ip_address(ip))
 
     ip_header_keys = ('version', 'tos', 'len', 'id', 'flags', 'ttl', 'protocol', 'checksum', 'src_addr', 'dest_addr')
     ip_header = dict(zip(ip_header_keys, struct.unpack(IP_HEADER_FORMAT, raw)))
@@ -276,7 +276,11 @@ def ping(dest_addr: str, timeout: int = 4, unit: str = "s", src_addr: str = None
     Raises:
         PingError: Any PingError will raise again if `ping3.EXCEPTIONS` is True.
     """
-    with socket.socket(socket.AF_INET, socket.SOCK_RAW, socket.IPPROTO_ICMP) as sock:
+    if platform.system() == "Darwin":
+        socket_type = socket.SOCK_DGRAM
+    else:
+        socket_type = socket.SOCK_RAW
+    with socket.socket(socket.AF_INET, socket_type, socket.IPPROTO_ICMP) as sock:
         if ttl:
             try:  # IPPROTO_IP is for Windows and BSD Linux.
                 if sock.getsockopt(socket.IPPROTO_IP, socket.IP_TTL):
@@ -322,7 +326,7 @@ def verbose_ping(dest_addr: str, count: int = 4, interval: float = 0, *args, **k
 
     Args:
         dest_addr: The destination address. Ex. "192.168.1.1"/"example.com"
-        count: How many pings should be sent. Default is 4, same as Windows CMD. (default 4)
+        count: How many pings should be sent. 0 means endless loop until manually stopped. Default is 4, same as Windows CMD. (default 4)
         interval: How many seconds between two packets. Default is 0, which means send the next packet as soon as the previous one responsed. (default 0)
         *args and **kwargs: And all the other arguments available in ping() except `seq`.
 
@@ -332,7 +336,10 @@ def verbose_ping(dest_addr: str, count: int = 4, interval: float = 0, *args, **k
     timeout = kwargs.get("timeout")
     src = kwargs.get("src")
     unit = kwargs.setdefault("unit", "ms")
-    for i in range(count):
+    i = 0
+    while i < count or count == 0:
+        if interval > 0 and i > 0:
+            time.sleep(interval)
         output_text = "ping '{}'".format(dest_addr)
         output_text += " from '{}'".format(src) if src else ""
         output_text += " ... "
@@ -342,8 +349,7 @@ def verbose_ping(dest_addr: str, count: int = 4, interval: float = 0, *args, **k
             print("Timeout > {}s".format(timeout) if timeout else "Timeout")
         else:
             print("{value}{unit}".format(value=int(delay), unit=unit))
-        if interval > 0 and i < (count - 1):
-            time.sleep(interval)
+        i += 1
 
 
 if __name__ == "__main__":
